@@ -155,6 +155,8 @@ void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_
     char * decrypted_data_c;
     char * decrypted_orig;
     char *ptr;
+    int is_notification_job = FALSE;
+    int is_eventhandler_job = FALSE;
 
     /* reset timeout for now, will be set befor execution again */
     alarm(0);
@@ -262,6 +264,12 @@ void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_
         } else if ( !strcmp( key, "command_line" ) ) {
             exec_job->command_line = gm_strdup(value);
             valid_lines++;
+        } else if ( !strcmp( key, "plugin_output" ) ) {
+            exec_job->output = gm_strdup(value);
+            valid_lines++;
+        } else if ( !strcmp( key, "long_plugin_output" ) ) {
+            exec_job->long_output = gm_strdup(value);
+            valid_lines++;
         }
     }
 
@@ -270,6 +278,34 @@ void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_
         write_debug_file(&decrypted_orig);
 #endif
 
+    if(!strcmp( exec_job->type, "notification")) {
+        is_notification_job = TRUE;
+    }
+    else if ( !strcmp( exec_job->type, "eventhandler" ) ) {
+        is_eventhandler_job = TRUE;
+    }
+
+    /* put plugin_output and long_plugin_output into the environment
+     * which is especcially useful for notifications
+     */
+    if(is_notification_job == TRUE) {
+        if(exec_job->service_description != NULL) {
+            if(exec_job->output != NULL)
+                setenv("NAGIOS_SERVICEOUTPUT",exec_job->output,1);
+            if(exec_job->long_output != NULL)
+                setenv("NAGIOS_LONGSERVICEOUTPUT",exec_job->output,1);
+        } else {
+            if(exec_job->output != NULL)
+                setenv("NAGIOS_HOSTOUTPUT",exec_job->output,1);
+            if(exec_job->long_output != NULL)
+                setenv("NAGIOS_LONGHOSTOUTPUT",exec_job->output,1);
+        }
+    }
+
+    /* will be overwritten */
+    if(exec_job->output != NULL)
+        free(exec_job->output);
+
     if(valid_lines == 0) {
         gm_log( GM_LOG_ERROR, "discarded invalid job (%s), check your encryption settings\n", gearman_job_handle( job ) );
     } else {
@@ -281,10 +317,32 @@ void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_
     /* start listening to SIGTERMs */
     sigprocmask(SIG_UNBLOCK, &block_mask, NULL);
 
+    /* log errors for notifications and eventhandler */
+    if((is_notification_job || is_eventhandler_job) && exec_job->return_code != 0) {
+        gm_log( GM_LOG_ERROR, "%s %s exited with return code %d\n",
+               exec_job->service_description != NULL ? "service" : "host",
+               exec_job->type,
+               exec_job->return_code
+        );
+        gm_log( GM_LOG_ERROR, "cmd: %s\n", exec_job->output );
+        gm_log( GM_LOG_ERROR, "output: %s\n" );
+    }
+
     free(decrypted_orig);
     free(decrypted_data_c);
     free_job(exec_job);
 
+    if(is_notification_job == TRUE) {
+        /* clear the environment */
+        if(exec_job->service_description != NULL) {
+            setenv("NAGIOS_SERVICEOUTPUT",NULL,1);
+            setenv("NAGIOS_LONGSERVICEOUTPUT",NULL,1);
+        } else {
+            setenv("NAGIOS_HOSTOUTPUT",NULL,1);
+            setenv("NAGIOS_LONGHOSTOUTPUT",NULL,1);
+        }
+    }
+
     /* send finish signal to parent */
     set_state(GM_JOB_END);
 
@@ -317,6 +375,9 @@ void do_exec_job( ) {
     else if ( !strcmp( exec_job->type, "eventhandler" ) ) {
         gm_log( GM_LOG_DEBUG, "got eventhandler job\n");
     }
+    else if ( !strcmp( exec_job->type, "notification" ) ) {
+        gm_log( GM_LOG_DEBUG, "got notification job\n");
+    }
 
     /* check proper timeout value */
     if( exec_job->timeout <= 0 ) {
@@ -338,7 +399,7 @@ void do_exec_job( ) {
         if ( !strcmp( exec_job->type, "service" ) ) {
             gm_log( GM_LOG_INFO, "discarded too old %s job: %i > %i (%s - %s)\n", exec_job->type, (int)age, mod_gm_opt->max_age, exec_job->host_name, exec_job->service_description);
         } else if ( !strcmp( exec_job->type, "host" ) ) {
-            gm_log( GM_LOG_INFO, "discarded too old %s job: %i > %i (%s - %s)\n", exec_job->type, (int)age, mod_gm_opt->max_age, exec_job->host_name);
+            gm_log( GM_LOG_INFO, "discarded too old %s job: %i > %i (%s)\n", exec_job->type, (int)age, mod_gm_opt->max_age, exec_job->host_name);
         } else {
             gm_log( GM_LOG_INFO, "discarded too old %s job: %i > %i\n", exec_job->type, (int)age, mod_gm_opt->max_age);
         }
@@ -395,6 +456,9 @@ int set_worker( gearman_worker_st *w ) {
         if(mod_gm_opt->events == GM_ENABLED)
             worker_add_function( w, "eventhandler", get_job );
 
+        if(mod_gm_opt->notifications == GM_ENABLED)
+            worker_add_function( w, "notification", get_job );
+
         while ( mod_gm_opt->hostgroups_list[x] != NULL ) {
             char buffer[GM_BUFFERSIZE];
             snprintf( buffer, (sizeof(buffer)-1), "hostgroup_%s", mod_gm_opt->hostgroups_list[x] );
